@@ -35,8 +35,8 @@
 /*
  * glcurveval.c++
  *
- * $Date: 2001/08/07 17:34:10 $ $Revision: 1.3 $
- * $Header: /cvsroot/mesa3d/Mesa/si-glu/libnurbs/interface/glcurveval.cc,v 1.3 2001/08/07 17:34:10 brianp Exp $
+ * $Date: 2003/04/30 15:20:07 $ $Revision: 1.4.2.1 $
+ * $Header: /cvsroot/mesa3d/Mesa/si-glu/libnurbs/interface/glcurveval.cc,v 1.4.2.1 2003/04/30 15:20:07 brianp Exp $
  */
 
 /* Polynomial Evaluator Interface */
@@ -151,7 +151,7 @@ OpenGLCurveEvaluator::mapgrid1f(long nu, REAL u0, REAL u1)
     {
       global_grid_u0 = u0;
       global_grid_u1 = u1;
-      global_grid_nu = nu;
+      global_grid_nu = (int) nu;
     }
   else
     glMapGrid1f((GLint) nu, (GLfloat) u0, (GLfloat) u1);
