@@ -1,4 +1,3 @@
-/* $Id: fxsetup.c,v 1.37 2002/06/15 03:03:10 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -1173,7 +1172,7 @@ fxSetupBlend(GLcontext * ctx)
 /************************************************************************/
 
 void
-fxDDAlphaFunc(GLcontext * ctx, GLenum func, GLchan ref)
+fxDDAlphaFunc(GLcontext * ctx, GLenum func, GLfloat ref)
 {
    fxMesaContext fxMesa = (fxMesaContext) ctx->DriverCtx;
    tfxUnitsState *us = &fxMesa->unitsState;
@@ -1229,8 +1228,9 @@ fxSetupAlphaTest(GLcontext * ctx)
    tfxUnitsState *us = &fxMesa->unitsState;
 
    if (us->alphaTestEnabled) {
+      GrAlpha_t ref = (GLint) (us->alphaTestRefValue * 255.0);
       FX_grAlphaTestFunction(us->alphaTestFunc);
-      FX_grAlphaTestReferenceValue(us->alphaTestRefValue);
+      FX_grAlphaTestReferenceValue(ref);
    }
    else
       FX_grAlphaTestFunction(GR_CMP_ALWAYS);
