@@ -1,4 +1,3 @@
-/* $Id: wmesa.c,v 1.41 2002/10/24 23:57:23 brianp Exp $ */
 
 /*
  * Windows (Win32) device driver for Mesa 3.4
@@ -407,7 +406,7 @@ static clear(GLcontext* ctx, GLbitfield mask,
   assert((mask & (DD_FRONT_RIGHT_BIT | DD_BACK_RIGHT_BIT)) == 0); 
   
   /* clear alpha */
-  if ((mask & (DD_FRONT_LEFT_BIT | DD_BACK_RIGHT_BIT)) &&
+  if ((mask & (DD_FRONT_LEFT_BIT | DD_BACK_LEFT_BIT)) &&
       ctx->DrawBuffer->UseSoftwareAlphaBuffers &&
       ctx->Color.ColorMask[ACOMP]) {
       _mesa_clear_alpha_buffers( ctx );
@@ -1352,6 +1351,7 @@ WMesaContext WMesaCreateContext( HWND hWnd, HPALETTE* Pal,
   
   _mesa_enable_sw_extensions(c->gl_ctx);
   _mesa_enable_1_3_extensions(c->gl_ctx);
+  _mesa_enable_1_4_extensions(c->gl_ctx);
 
   c->gl_buffer = _mesa_create_framebuffer( c->gl_visual,
 					   c->gl_visual->depthBits > 0,
