@@ -17,6 +17,7 @@
 #include <GL\wmesa.h>
 #include "context.h"
 #include "dd.h"
+#include "imports.h"
 #include "xform.h"
 #include "vb.h"
 #include "matrix.h"
@@ -152,10 +153,14 @@ static void clear_index(GLcontext* ctx, GLuint index)
 /*
  * Set the color used to clear the color buffer.
  */
-static void clear_color( GLcontext* ctx, const GLchan color[4] )
+static void clear_color( GLcontext* ctx, const GLfloat color[4] )
 {
   STARTPROFILE
-  Current->clearpixel = RGB(color[0], color[1], color[2]);
+  GLubyte col[4];
+  CLAMPED_FLOAT_TO_UBYTE(col[0], color[0]);
+  CLAMPED_FLOAT_TO_UBYTE(col[1], color[1]);
+  CLAMPED_FLOAT_TO_UBYTE(col[2], color[2]);
+  Current->clearpixel = RGB(col[0], col[1], col[2]);
   ENDPROFILE(clear_color)
 }
 
@@ -420,7 +425,7 @@ extern points_func choose_points_function( GLcontext* ctx )
 {
    STARTPROFILE
    if (ctx->Point.Size==1.0 && !ctx->Point.SmoothFlag && ctx->_RasterMask==0
-       && !ctx->Texture._ReallyEnabled  && ctx->Visual->RGBAflag) {
+       && ctx->Texture._EnabledUnits == 0 && ctx->Visual->RGBAflag) {
    ENDPROFILE(choose_points_function)
       return fast_rgb_points;
    }
@@ -478,7 +483,7 @@ static line_func choose_line_function( GLcontext* ctx )
 	STARTPROFILE
    if (ctx->Line.Width==1.0 && !ctx->Line.SmoothFlag && !ctx->Line.StippleFlag
        && ctx->Light.ShadeModel==GL_FLAT && ctx->_RasterMask==0
-       && !ctx->Texture._ReallyEnabled && Current->rgb_flag) {
+       && ctx->Texture._EnabledUnits == 0 && Current->rgb_flag) {
    ENDPROFILE(choose_line_function)
       return fast_flat_rgb_line;
    }
@@ -589,7 +594,7 @@ static triangle_func choose_triangle_function( GLcontext *ctx )
 {
    if (ctx->Polygon.SmoothFlag)     return NULL;
    if (ctx->Polygon.StippleFlag)    return NULL;
-   if (ctx->Texture._ReallyEnabled)  return NULL;
+   if (ctx->Texture._EnabledUnits)  return NULL;
 
    if (ctx->_RasterMask==DEPTH_BIT
        && ctx->Depth.Func==GL_LESS
@@ -660,7 +665,7 @@ static polygon_func choose_polygon_function( GLcontext* ctx )
    STARTPROFILE
    if (!ctx->Polygon.SmoothFlag && !ctx->Polygon.StippleFlag
        && ctx->Light.ShadeModel==GL_FLAT && ctx->_RasterMask==0
-       && !ctx->Texture._ReallyEnabled && Current->rgb_flag==GL_TRUE) {
+       && ctx->Texture._EnabledUnits == 0 && Current->rgb_flag==GL_TRUE) {
       ENDPROFILE(choose_polygon_function)
       return fast_flat_rgb_polygon;
    }
@@ -1196,7 +1201,7 @@ WMesaContext /*APIENTRY*/ WMesaCreateContext( HWND hWnd, HPALETTE Pal,
       }
 
   /* allocate a new Mesa context */
-  c->gl_ctx = _mesa_create_context( c->gl_visual, NULL,c);
+  c->gl_ctx = _mesa_create_context( c->gl_visual, NULL, (void *) g, GL_FALSE );
 
   if (!c->gl_ctx) {
          _mesa_destroy_visual( c->gl_visual );
