@@ -1,8 +1,6 @@
-/* $Id: extensions.c,v 1.85.2.1 2003/02/28 16:28:11 brianp Exp $ */
-
 /*
  * Mesa 3-D graphics library
- * Version:  5.0.1
+ * Version:  5.0.2
  *
  * Copyright (C) 1999-2003  Brian Paul   All Rights Reserved.
  *
@@ -46,7 +44,7 @@ struct extension {
 #define ON GL_TRUE
 #define OFF GL_FALSE
 
-static struct {
+static const struct {
    GLboolean enabled;
    const char *name;
    int flag_offset;
@@ -68,8 +66,6 @@ static struct {
    { OFF, "GL_ARB_texture_mirrored_repeat",    F(ARB_texture_mirrored_repeat)},
    { ON,  "GL_ARB_transpose_matrix",           0 },
    { ON,  "GL_ARB_window_pos",                 F(ARB_window_pos) },
-   { OFF, "GL_ATI_texture_env_combine3",       F(ATI_texture_env_combine3)},
-   { OFF, "GL_ATI_texture_mirror_once",        F(ATI_texture_mirror_once)},
    { ON,  "GL_EXT_abgr",                       0 },
    { ON,  "GL_EXT_bgra",                       0 },
    { OFF, "GL_EXT_blend_color",                F(EXT_blend_color) },
@@ -77,22 +73,27 @@ static struct {
    { OFF, "GL_EXT_blend_logic_op",             F(EXT_blend_logic_op) },
    { OFF, "GL_EXT_blend_minmax",               F(EXT_blend_minmax) },
    { OFF, "GL_EXT_blend_subtract",             F(EXT_blend_subtract) },
-   { ON,  "GL_EXT_clip_volume_hint",           F(EXT_clip_volume_hint) },
-   { OFF, "GL_EXT_convolution",                F(EXT_convolution) },
+   { ON,  "GL_EXT_clip_volume_hint",           0 },
    { ON,  "GL_EXT_compiled_vertex_array",      F(EXT_compiled_vertex_array) },
+   { OFF, "GL_EXT_convolution",                F(EXT_convolution) },
+   { ON,  "GL_EXT_copy_texture",               0 },
+   { ON,  "GL_EXT_draw_range_elements",        0 },
    { OFF, "GL_EXT_fog_coord",                  F(EXT_fog_coord) },
    { OFF, "GL_EXT_histogram",                  F(EXT_histogram) },
    { OFF, "GL_EXT_multi_draw_arrays",          F(EXT_multi_draw_arrays) },
-   { ON,  "GL_EXT_packed_pixels",              F(EXT_packed_pixels) },
+   { ON,  "GL_EXT_packed_pixels",              0 },
    { OFF, "GL_EXT_paletted_texture",           F(EXT_paletted_texture) },
    { OFF, "GL_EXT_point_parameters",           F(EXT_point_parameters) },
-   { ON,  "GL_EXT_polygon_offset",             F(EXT_polygon_offset) },
-   { ON,  "GL_EXT_rescale_normal",             F(EXT_rescale_normal) },
+   { ON,  "GL_EXT_polygon_offset",             0 },
+   { ON,  "GL_EXT_rescale_normal",             0 },
    { OFF, "GL_EXT_secondary_color",            F(EXT_secondary_color) },
+   { ON,  "GL_EXT_separate_specular_color",    0 },
    { OFF, "GL_EXT_shadow_funcs",               F(EXT_shadow_funcs) },
    { OFF, "GL_EXT_shared_texture_palette",     F(EXT_shared_texture_palette) },
-   { OFF, "GL_EXT_stencil_wrap",               F(EXT_stencil_wrap) },
    { OFF, "GL_EXT_stencil_two_side",           F(EXT_stencil_two_side) },
+   { OFF, "GL_EXT_stencil_wrap",               F(EXT_stencil_wrap) },
+   { ON,  "GL_EXT_subtexture",                 0 },
+   { ON,  "GL_EXT_texture",                    0 },
    { ON,  "GL_EXT_texture3D",                  F(EXT_texture3D) },
    { OFF, "GL_EXT_texture_compression_s3tc",   F(EXT_texture_compression_s3tc) },
    { OFF, "GL_EXT_texture_edge_clamp",         F(SGIS_texture_edge_clamp) },
@@ -100,23 +101,29 @@ static struct {
    { OFF, "GL_EXT_texture_env_combine",        F(EXT_texture_env_combine) },
    { OFF, "GL_EXT_texture_env_dot3",           F(EXT_texture_env_dot3) },
    { OFF, "GL_EXT_texture_filter_anisotropic", F(EXT_texture_filter_anisotropic) },
-   { ON,  "GL_EXT_texture_object",             F(EXT_texture_object) },
+   { ON,  "GL_EXT_texture_object",             0 },
    { OFF, "GL_EXT_texture_lod_bias",           F(EXT_texture_lod_bias) },
+   { OFF, "GL_EXT_texture_rectangle",          F(NV_texture_rectangle) },
    { ON,  "GL_EXT_vertex_array",               0 },
    { OFF, "GL_EXT_vertex_array_set",           F(EXT_vertex_array_set) },
+   { OFF, "GL_3DFX_texture_compression_FXT1",  F(TDFX_texture_compression_FXT1) },
+   { OFF, "GL_APPLE_client_storage",           F(APPLE_client_storage) },
+   { ON,  "GL_APPLE_packed_pixels",            0 },
+   { OFF, "GL_ATI_texture_env_combine3",       F(ATI_texture_env_combine3)},
+   { OFF, "GL_ATI_texture_mirror_once",        F(ATI_texture_mirror_once)},
    { OFF, "GL_HP_occlusion_test",              F(HP_occlusion_test) },
    { ON,  "GL_IBM_rasterpos_clip",             F(IBM_rasterpos_clip) },
    { OFF, "GL_IBM_texture_mirrored_repeat",    F(ARB_texture_mirrored_repeat)},
-   { OFF, "GL_INGR_blend_func_separate",       F(INGR_blend_func_separate) },
+   { OFF, "GL_INGR_blend_func_separate",       F(EXT_blend_func_separate) },
    { OFF, "GL_MESA_pack_invert",               F(MESA_pack_invert) },
    { OFF, "GL_MESA_packed_depth_stencil",      0 },
    { OFF, "GL_MESA_resize_buffers",            F(MESA_resize_buffers) },
    { OFF, "GL_MESA_ycbcr_texture",             F(MESA_ycbcr_texture) },
-   { ON,  "GL_MESA_window_pos",                F(MESA_window_pos) },
+   { ON,  "GL_MESA_window_pos",                F(ARB_window_pos) },
    { OFF, "GL_NV_blend_square",                F(NV_blend_square) },
    { OFF, "GL_NV_point_sprite",                F(NV_point_sprite) },
    { OFF, "GL_NV_texture_rectangle",           F(NV_texture_rectangle) },
-   { ON,  "GL_NV_texgen_reflection",           F(NV_texgen_reflection) },
+   { ON,  "GL_NV_texgen_reflection",           0 },
    { OFF, "GL_NV_vertex_program",              F(NV_vertex_program) },
    { OFF, "GL_NV_vertex_program1_1",           F(NV_vertex_program1_1) },
    { OFF, "GL_SGI_color_matrix",               F(SGI_color_matrix) },
@@ -125,12 +132,11 @@ static struct {
    { OFF, "GL_SGIS_pixel_texture",             F(SGIS_pixel_texture) },
    { OFF, "GL_SGIS_texture_border_clamp",      F(ARB_texture_border_clamp) },
    { OFF, "GL_SGIS_texture_edge_clamp",        F(SGIS_texture_edge_clamp) },
+   { ON,  "GL_SGIS_texture_lod",               0 },
    { OFF, "GL_SGIX_depth_texture",             F(SGIX_depth_texture) },
    { OFF, "GL_SGIX_pixel_texture",             F(SGIX_pixel_texture) },
    { OFF, "GL_SGIX_shadow",                    F(SGIX_shadow) },
    { OFF, "GL_SGIX_shadow_ambient",            F(SGIX_shadow_ambient) },
-   { OFF, "GL_3DFX_texture_compression_FXT1",  F(TDFX_texture_compression_FXT1) },
-   { OFF, "GL_APPLE_client_storage",           F(APPLE_client_storage) }
 };
 
 
@@ -158,6 +164,7 @@ _mesa_enable_sw_extensions(GLcontext *ctx)
       "GL_ARB_texture_env_dot3",
       "GL_ARB_texture_mirrored_repeat",
       "GL_ATI_texture_mirror_once",
+      "GL_ATI_texture_env_combine3",
       "GL_EXT_blend_color",
       "GL_EXT_blend_func_separate",
       "GL_EXT_blend_logic_op",
@@ -178,6 +185,7 @@ _mesa_enable_sw_extensions(GLcontext *ctx)
       "GL_EXT_texture_env_combine",
       "GL_EXT_texture_env_dot3",
       "GL_EXT_texture_lod_bias",
+      "GL_EXT_texture_rectangle",
       "GL_HP_occlusion_test",
       "GL_IBM_texture_mirrored_repeat",
       "GL_INGR_blend_func_separate",
@@ -287,6 +295,7 @@ _mesa_enable_1_4_extensions(GLcontext *ctx)
       "GL_EXT_multi_draw_arrays",
       "GL_EXT_secondary_color",
       "GL_EXT_stencil_wrap",
+      "GL_EXT_texture_lod_bias",
       "GL_SGIS_generate_mipmap",
       NULL
    };
