@@ -1,4 +1,3 @@
-/* $Id: m_debug_norm.c,v 1.10 2002/10/24 23:57:24 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -24,7 +23,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
  * Authors:
- *    Gareth Hughes <gareth@valinux.com>
+ *    Gareth Hughes
  */
 
 #include "glheader.h"
@@ -291,15 +290,15 @@ static int test_norm_function( normal_func func, int mtype, long *cycles )
    for ( i = 0 ; i < TEST_COUNT ; i++ ) {
       for ( j = 0 ; j < 3 ; j++ ) {
          if ( significand_match( d[i][j], r[i][j] ) < REQUIRED_PRECISION ) {
-            _mesa_printf(NULL, "-----------------------------\n" );
-            _mesa_printf(NULL, "(i = %i, j = %i)\n", i, j );
-            _mesa_printf(NULL, "%f \t %f \t [ratio = %e - %i bit missed]\n",
+            _mesa_printf( "-----------------------------\n" );
+            _mesa_printf( "(i = %i, j = %i)\n", i, j );
+            _mesa_printf( "%f \t %f \t [ratio = %e - %i bit missed]\n",
 		    d[i][0], r[i][0], r[i][0]/d[i][0],
 		    MAX_PRECISION - significand_match( d[i][0], r[i][0] ) );
-            _mesa_printf(NULL, "%f \t %f \t [ratio = %e - %i bit missed]\n",
+            _mesa_printf( "%f \t %f \t [ratio = %e - %i bit missed]\n",
 		    d[i][1], r[i][1], r[i][1]/d[i][1],
 		    MAX_PRECISION - significand_match( d[i][1], r[i][1] ) );
-            _mesa_printf(NULL, "%f \t %f \t [ratio = %e - %i bit missed]\n",
+            _mesa_printf( "%f \t %f \t [ratio = %e - %i bit missed]\n",
 		    d[i][2], r[i][2], r[i][2]/d[i][2],
 		    MAX_PRECISION - significand_match( d[i][2], r[i][2] ) );
             return 0;
@@ -307,15 +306,15 @@ static int test_norm_function( normal_func func, int mtype, long *cycles )
 
          if ( norm_normalize_types[mtype] != 0 ) {
             if ( significand_match( d2[i][j], r2[i][j] ) < REQUIRED_PRECISION ) {
-               _mesa_printf(NULL, "------------------- precalculated length case ------\n" );
-               _mesa_printf(NULL, "(i = %i, j = %i)\n", i, j );
-               _mesa_printf(NULL, "%f \t %f \t [ratio = %e - %i bit missed]\n",
+               _mesa_printf( "------------------- precalculated length case ------\n" );
+               _mesa_printf( "(i = %i, j = %i)\n", i, j );
+               _mesa_printf( "%f \t %f \t [ratio = %e - %i bit missed]\n",
 		       d2[i][0], r2[i][0], r2[i][0]/d2[i][0],
 		       MAX_PRECISION - significand_match( d2[i][0], r2[i][0] ) );
-               _mesa_printf(NULL, "%f \t %f \t [ratio = %e - %i bit missed]\n",
+               _mesa_printf( "%f \t %f \t [ratio = %e - %i bit missed]\n",
 		       d2[i][1], r2[i][1], r2[i][1]/d2[i][1],
 		       MAX_PRECISION - significand_match( d2[i][1], r2[i][1] ) );
-               _mesa_printf(NULL, "%f \t %f \t [ratio = %e - %i bit missed]\n",
+               _mesa_printf( "%f \t %f \t [ratio = %e - %i bit missed]\n",
 		       d2[i][2], r2[i][2], r2[i][2]/d2[i][2],
 		       MAX_PRECISION - significand_match( d2[i][2], r2[i][2] ) );
                return 0;
@@ -343,11 +342,11 @@ void _math_test_all_normal_transform_functions( char *description )
    if ( mesa_profile ) {
       if ( !counter_overhead ) {
 	 INIT_COUNTER();
-	 _mesa_printf(NULL, "counter overhead: %ld cycles\n\n", counter_overhead );
+	 _mesa_printf( "counter overhead: %ld cycles\n\n", counter_overhead );
       }
-      _mesa_printf(NULL, "normal transform results after hooking in %s functions:\n",
+      _mesa_printf( "normal transform results after hooking in %s functions:\n",
 	      description );
-      _mesa_printf(NULL, "\n-------------------------------------------------------\n" );
+      _mesa_printf( "\n-------------------------------------------------------\n" );
    }
 #endif
 
@@ -357,21 +356,21 @@ void _math_test_all_normal_transform_functions( char *description )
 
       if ( test_norm_function( func, mtype, cycles ) == 0 ) {
 	 char buf[100];
-	 _mesa_sprintf(NULL, buf, "_mesa_normal_tab[0][%s] failed test (%s)",
+	 _mesa_sprintf( buf, "_mesa_normal_tab[0][%s] failed test (%s)",
 		  norm_strings[mtype], description );
 	 _mesa_problem( NULL, buf );
       }
 
 #ifdef RUN_DEBUG_BENCHMARK
       if ( mesa_profile ) {
-	 _mesa_printf(NULL, " %li\t", benchmark_tab[mtype] );
-	 _mesa_printf(NULL, " | [%s]\n", norm_strings[mtype] );
+	 _mesa_printf( " %li\t", benchmark_tab[mtype] );
+	 _mesa_printf( " | [%s]\n", norm_strings[mtype] );
       }
 #endif
    }
 #ifdef RUN_DEBUG_BENCHMARK
    if ( mesa_profile ) {
-      _mesa_printf(NULL, "\n" );
+      _mesa_printf( "\n" );
       fflush( stdout );
    }
 #endif
