@@ -1,8 +1,6 @@
-/* $Id: mmath.h,v 1.63.2.3 2003/02/05 23:19:58 brianp Exp $ */
-
 /*
  * Mesa 3-D graphics library
- * Version:  5.0.1
+ * Version:  5.0.2
  *
  * Copyright (C) 1999-2003  Brian Paul   All Rights Reserved.
  *
@@ -189,22 +187,19 @@ do {						\
 /*
  * Single precision ceiling, floor, and absolute value functions
  */
-#if defined(__sparc__) || defined(__NeXT__) /* XXX this probably isn't the ideal test */
-#define CEILF(x)   ceil(x)
-#define FLOORF(x)  floor(x)
-#define FABSF(x)   fabs(x)
-#elif defined(__WIN32__) || defined(__IBMC__) || defined(__IBMCPP__)
-#define CEILF(x)   ((GLfloat)ceil(x))
-#define FLOORF(x)  ((GLfloat)floor(x))
-#define FABSF(x)   ((GLfloat)fabs(x))
-#elif defined(XFree86LOADER) && defined(IN_MODULE)
+#if defined(XFree86LOADER) && defined(IN_MODULE)
 #define CEILF(x)   ((GLfloat) xf86ceil(x))
 #define FLOORF(x)  ((GLfloat) xf86floor(x))
 #define FABSF(x)   ((GLfloat) xf86fabs(x))
-#else
+#elif defined(__gnu_linux__)
+/* C99 functions */
 #define CEILF(x)   ceilf(x)
 #define FLOORF(x)  floorf(x)
 #define FABSF(x)   fabsf(x)
+#else
+#define CEILF(x)   ((GLfloat) ceil(x))
+#define FLOORF(x)  ((GLfloat) floor(x))
+#define FABSF(x)   ((GLfloat) fabs(x))
 #endif
 
 
