@@ -1,4 +1,3 @@
-/* $Id: mtypes.h,v 1.97.2.2 2003/03/02 19:31:48 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -867,6 +866,7 @@ struct gl_texture_object {
    GLenum MagFilter;		/* magnification filter */
    GLfloat MinLod;		/* min lambda, OpenGL 1.2 */
    GLfloat MaxLod;		/* max lambda, OpenGL 1.2 */
+   GLfloat LodBias;		/* lod bias, OpenGL 1.4 */
    GLint BaseLevel;		/* min mipmap level, OpenGL 1.2 */
    GLint MaxLevel;		/* max mipmap level, OpenGL 1.2 */
    GLfloat MaxAnisotropy;	/* GL_EXT_texture_filter_anisotropic */
@@ -1374,17 +1374,13 @@ struct gl_extensions {
    GLboolean EXT_blend_logic_op;
    GLboolean EXT_blend_minmax;
    GLboolean EXT_blend_subtract;
-   GLboolean EXT_clip_volume_hint;
    GLboolean EXT_convolution;
    GLboolean EXT_compiled_vertex_array;
    GLboolean EXT_fog_coord;
    GLboolean EXT_histogram;
    GLboolean EXT_multi_draw_arrays;
-   GLboolean EXT_packed_pixels;
    GLboolean EXT_paletted_texture;
    GLboolean EXT_point_parameters;
-   GLboolean EXT_polygon_offset;
-   GLboolean EXT_rescale_normal;
    GLboolean EXT_shadow_funcs;
    GLboolean EXT_secondary_color;
    GLboolean EXT_shared_texture_palette;
@@ -1396,20 +1392,16 @@ struct gl_extensions {
    GLboolean EXT_texture_env_combine;
    GLboolean EXT_texture_env_dot3;
    GLboolean EXT_texture_filter_anisotropic;
-   GLboolean EXT_texture_object;
    GLboolean EXT_texture_lod_bias;
    GLboolean EXT_vertex_array_set;
    GLboolean HP_occlusion_test;
    GLboolean IBM_rasterpos_clip;
-   GLboolean INGR_blend_func_separate;
    GLboolean MESA_pack_invert;
-   GLboolean MESA_window_pos;
    GLboolean MESA_resize_buffers;
    GLboolean MESA_ycbcr_texture;
    GLboolean NV_blend_square;
    GLboolean NV_point_sprite;
    GLboolean NV_texture_rectangle;
-   GLboolean NV_texgen_reflection;
    GLboolean NV_vertex_program;
    GLboolean NV_vertex_program1_1;
    GLboolean SGI_color_matrix;
