@@ -1,10 +1,8 @@
-/* $Id: s_drawpix.c,v 1.38 2002/10/24 23:57:24 brianp Exp $ */
-
 /*
  * Mesa 3-D graphics library
- * Version:  4.1
+ * Version:  5.0.2
  *
- * Copyright (C) 1999-2002  Brian Paul   All Rights Reserved.
+ * Copyright (C) 1999-2003  Brian Paul   All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -114,6 +112,8 @@ fast_draw_pixels(GLcontext *ctx, GLint x, GLint y,
       _mesa_span_default_z(ctx, &span);
    if (ctx->Fog.Enabled)
       _mesa_span_default_fog(ctx, &span);
+   if (ctx->Texture._EnabledUnits)
+      _mesa_span_default_texcoords(ctx, &span);
 
    if ((SWRAST_CONTEXT(ctx)->_RasterMask & ~CLIP_BIT) == 0
        && ctx->Texture._EnabledUnits == 0
@@ -684,21 +684,14 @@ draw_depth_pixels( GLcontext *ctx, GLint x, GLint y,
                span.array->z[i] = (GLdepth) (fspan[i] * zs + 0.5F);
             }
          }
-         if (ctx->Visual.rgbMode) {
-            if (zoom) {
-               abort();
-               _mesa_write_zoomed_rgba_span(ctx, &span,
-                                 (const GLchan (*)[4]) span.array->rgba, desty);
-            }
-            else
-               _mesa_write_rgba_span(ctx, &span);
+         if (zoom) {
+            _mesa_write_zoomed_depth_span(ctx, &span, desty);
+         }
+         else if (ctx->Visual.rgbMode) {
+            _mesa_write_rgba_span(ctx, &span);
          }
          else {
-               abort();
-            if (zoom)
-               _mesa_write_zoomed_index_span(ctx, &span, desty);
-            else
-               _mesa_write_index_span(ctx, &span);
+            _mesa_write_index_span(ctx, &span);
          }
       }
    }
